==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/gui/views/dialogs/editPreferences/DevicePanel.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.views.dialogs.editPreferences;

import java.awt.GridBagConstraints;
import java.awt.GridLayout;
import java.util.HashMap;
import java.util.Map;

import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

import net.sourceforge.atunes.gui.views.controls.CustomJFileChooser;
import net.sourceforge.atunes.utils.LanguageTool;
import net.sourceforge.atunes.utils.StringUtils;

/**
 * The Class DevicePanel.
 */
public class DevicePanel extends PreferencesPanel {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 3331810461314007217L;

	/** The location file chooser. */
	private CustomJFileChooser locationFileChooser;

	/** The flat structure radio button. */
	private JRadioButton flatStructureRadioButton;

	/** The artist structure radio button. */
	private JRadioButton artistStructureRadioButton;

	/** The full structure radio button. */
	private JRadioButton fullStructureRadioButton;

	/**
	 * Instantiates a new device panel.
	 */
	public DevicePanel() {
		super();
		JLabel label = new JLabel(LanguageTool.getString("DEVICE_DEFAULT_LOCATION"));
		locationFileChooser = new CustomJFileChooser(this, 20, JFileChooser.DIRECTORIES_ONLY);

		JPanel exportStructurePanel = new JPanel(new GridLayout(3, 1));
		exportStructurePanel.setBorder(BorderFactory.createTitledBorder(BorderFactory.createEtchedBorder(1), LanguageTool.getString("STRUCTURE")));
		flatStructureRadioButton = new JRadioButton(LanguageTool.getString("FLAT"));
		artistStructureRadioButton = new JRadioButton(LanguageTool.getString("ARTIST"));
		fullStructureRadioButton = new JRadioButton(StringUtils.getString(LanguageTool.getString("ARTIST"), " / ", LanguageTool.getString("ALBUM")));
		ButtonGroup group2 = new ButtonGroup();
		group2.add(flatStructureRadioButton);
		group2.add(artistStructureRadioButton);
		group2.add(fullStructureRadioButton);
		exportStructurePanel.add(flatStructureRadioButton);
		exportStructurePanel.add(artistStructureRadioButton);
		exportStructurePanel.add(fullStructureRadioButton);

		GridBagConstraints c = new GridBagConstraints();
		c.gridx = 0;
		c.gridy = 0;
		c.weightx = 1;
		c.weighty = 0;
		c.fill = GridBagConstraints.HORIZONTAL;
		c.anchor = GridBagConstraints.NORTH;
		add(label, c);
		c.gridx = 1;
		add(locationFileChooser, c);
		c.weighty = 1;
		c.gridy = 1;
		c.gridx = 0;
		add(exportStructurePanel, c);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see net.sourceforge.atunes.gui.views.dialogs.editPreferences.PreferencesPanel#getResult()
	 */
	@SuppressWarnings("boxing")
	@Override
	public Map<String, Object> getResult() {
		Map<String, Object> result = new HashMap<String, Object>();
		result.put(LanguageTool.getString("DEVICE_DEFAULT_LOCATION"), locationFileChooser.getResult());
		result.put(LanguageTool.getString("FLAT"), flatStructureRadioButton.isSelected());
		result.put(LanguageTool.getString("ARTIST"), artistStructureRadioButton.isSelected());
		result.put(StringUtils.getString(LanguageTool.getString("ARTIST"), " / ", LanguageTool.getString("ALBUM")), fullStructureRadioButton.isSelected());
		return result;
	}

	/**
	 * Sets the default device location.
	 * 
	 * @param location
	 *            the new default device location
	 */
	public void setDefaultDeviceLocation(String location) {
		locationFileChooser.setText(location);
	}

	/**
	 * Sets the flat structure radio button.
	 * 
	 * @param selected
	 *            the new flat structure radio button
	 */
	public void setFlatStructureRadioButton(boolean selected) {
		flatStructureRadioButton.setSelected(selected);
	}

	/**
	 * Sets the artist structure radio button.
	 * 
	 * @param selected
	 *            the new artist structure radio button
	 */
	public void setArtistStructureRadioButton(boolean selected) {
		artistStructureRadioButton.setSelected(selected);
	}

	/**
	 * Sets the full structure radio button.
	 * 
	 * @param selected
	 *            the new full structure radio button
	 */
	public void setFullStructureRadioButton(boolean selected) {
		fullStructureRadioButton.setSelected(selected);
	}

}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/gui/views/dialogs/editPreferences/DevicePanel.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.gui.views.dialogs.editPreferences;

import java.awt.GridBagConstraints;
import java.awt.GridLayout;
import java.util.HashMap;
import java.util.Map;

import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;

import net.sourceforge.atunes.gui.views.controls.CustomJFileChooser;
import net.sourceforge.atunes.utils.LanguageTool;
import net.sourceforge.atunes.utils.StringUtils;

/**
 * The Class DevicePanel.
 */
public class DevicePanel extends PreferencesPanel {

	/** The Constant serialVersionUID. */
	private static final long serialVersionUID = 3331810461314007217L;

	/** The location file chooser. */
	private CustomJFileChooser locationFileChooser;

	/** The flat structure radio button. */
	private JRadioButton flatStructureRadioButton;

	/** The artist structure radio button. */
	private JRadioButton artistStructureRadioButton;

	/** The full structure radio button. */
	private JRadioButton fullStructureRadioButton;

	/**
	 * Instantiates a new device panel.
	 */
	public DevicePanel() {
		super();
		JLabel label = new JLabel(LanguageTool.getString("DEVICE_DEFAULT_LOCATION"));
		locationFileChooser = new CustomJFileChooser(this, 20, JFileChooser.DIRECTORIES_ONLY);

		JPanel exportStructurePanel = new JPanel(new GridLayout(3, 1));
		exportStructurePanel.setBorder(BorderFactory.createTitledBorder(LanguageTool.getString("STRUCTURE")));
		flatStructureRadioButton = new JRadioButton(LanguageTool.getString("FLAT"));
		artistStructureRadioButton = new JRadioButton(LanguageTool.getString("ARTIST"));
		fullStructureRadioButton = new JRadioButton(StringUtils.getString(LanguageTool.getString("ARTIST"), " / ", LanguageTool.getString("ALBUM")));
		ButtonGroup group2 = new ButtonGroup();
		group2.add(flatStructureRadioButton);
		group2.add(artistStructureRadioButton);
		group2.add(fullStructureRadioButton);
		exportStructurePanel.add(flatStructureRadioButton);
		exportStructurePanel.add(artistStructureRadioButton);
		exportStructurePanel.add(fullStructureRadioButton);

		GridBagConstraints c = new GridBagConstraints();
		c.gridx = 0;
		c.gridy = 0;
		c.weightx = 1;
		c.weighty = 0;
		c.fill = GridBagConstraints.HORIZONTAL;
		c.anchor = GridBagConstraints.NORTH;
		add(label, c);
		c.gridx = 1;
		add(locationFileChooser, c);
		c.weighty = 1;
		c.gridy = 1;
		c.gridx = 0;
		add(exportStructurePanel, c);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * net.sourceforge.atunes.gui.views.dialogs.editPreferences.PreferencesPanel
	 * #getResult()
	 */

	@Override
	public Map<String, Object> getResult() {
		Map<String, Object> result = new HashMap<String, Object>();
		result.put(LanguageTool.getString("DEVICE_DEFAULT_LOCATION"), locationFileChooser.getResult());
		result.put(LanguageTool.getString("FLAT"), flatStructureRadioButton.isSelected());
		result.put(LanguageTool.getString("ARTIST"), artistStructureRadioButton.isSelected());
		result.put(StringUtils.getString(LanguageTool.getString("ARTIST"), " / ", LanguageTool.getString("ALBUM")), fullStructureRadioButton.isSelected());
		return result;
	}

	/**
	 * Sets the default device location.
	 * 
	 * @param location
	 *            the new default device location
	 */
	public void setDefaultDeviceLocation(String location) {
		locationFileChooser.setText(location);
	}

	/**
	 * Sets the flat structure radio button.
	 * 
	 * @param selected
	 *            the new flat structure radio button
	 */
	public void setFlatStructureRadioButton(boolean selected) {
		flatStructureRadioButton.setSelected(selected);
	}

	/**
	 * Sets the artist structure radio button.
	 * 
	 * @param selected
	 *            the new artist structure radio button
	 */
	public void setArtistStructureRadioButton(boolean selected) {
		artistStructureRadioButton.setSelected(selected);
	}

	/**
	 * Sets the full structure radio button.
	 * 
	 * @param selected
	 *            the new full structure radio button
	 */
	public void setFullStructureRadioButton(boolean selected) {
		fullStructureRadioButton.setSelected(selected);
	}

}
